ResolvedHost

Struct ResolvedHost 

pub struct ResolvedHost {
Show 26 fields pub alias: String, pub host_name: Option<String>, pub user: Option<String>, pub port: Option<u16>, pub identity_files: Vec<String>, pub certificate_files: Vec<String>, pub proxy_jump: Option<String>, pub identity_agent: Option<String>, pub forward_agent: Option<String>, pub add_keys_to_agent: Option<String>, pub use_keychain: Option<String>, pub control_master: Option<String>, pub control_path: Option<String>, pub control_persist: Option<String>, pub local_forwards: Vec<String>, pub remote_forwards: Vec<String>, pub dynamic_forwards: Vec<String>, pub directives: Vec<(String, String)>, pub user_known_hosts_file: Option<String>, pub identities_only: Option<bool>, pub canonicalized: bool, pub unevaluated_match_warnings: Vec<String>, pub gssapi_authentication: Option<String>, pub gssapi_delegate_credentials: Option<String>, pub gssapi_server_identity: Option<String>, pub gssapi_client_identity: Option<String>,
}
Fully resolved parameters for a host.

Fields

alias: String

The alias used to look up the host.

host_name: Option<String>

The real hostname to connect to.

user: Option<String>

The user for the SSH connection.

port: Option<u16>

The port number.

identity_files: Vec<String>

Identity files to try.

certificate_files: Vec<String>

Certificate files (accumulative across matching blocks).

proxy_jump: Option<String>

ProxyJump hosts.

identity_agent: Option<String>

IdentityAgent socket path.

forward_agent: Option<String>

ForwardAgent setting (yes/no).

add_keys_to_agent: Option<String>

AddKeysToAgent setting (yes/confirm/ask/no/lifetime).

use_keychain: Option<String>

UseKeychain setting (yes/no, macOS only).

control_master: Option<String>

ControlMaster setting (yes/no/auto/ask/autoask).

control_path: Option<String>

ControlPath socket path.

control_persist: Option<String>

ControlPersist duration.

local_forwards: Vec<String>

LocalForward entries (accumulative).

remote_forwards: Vec<String>

RemoteForward entries (accumulative).

dynamic_forwards: Vec<String>

DynamicForward entries (accumulative).

directives: Vec<(String, String)>

All raw key-value directives from matching blocks.

user_known_hosts_file: Option<String>

UserKnownHostsFile value, if set.

When None, the default ~/.ssh/known_hosts is used. May contain SSH tokens (already expanded).

identities_only: Option<bool>

IdentitiesOnly setting parsed as a boolean (yes / no).

When Some(true), only the identity files explicitly listed in the config (and those on the command line) are offered during authentication. When Some(false) or None, keys from the agent and default key files are also tried.

canonicalized: bool

Whether the config was re-resolved after CanonicalizeHostname took effect. When true, %H tokens expand to the canonical hostname rather than the original alias.

unevaluated_match_warnings: Vec<String>

Warnings for Match blocks containing exec criteria that were not evaluated (toride does not execute arbitrary commands for security).

gssapi_authentication: Option<String>

GSSAPIAuthentication setting (yes/no).

gssapi_delegate_credentials: Option<String>

GSSAPIDelegateCredentials setting (yes/no).

gssapi_server_identity: Option<String>

GSSAPIServerIdentity value.

gssapi_client_identity: Option<String>

GSSAPIClientIdentity value.