pub enum ConfigNode {
BlankLine,
Comment {
text: String,
indent: String,
},
Directive(Box<DirectiveData>),
HostBlock(Box<HostBlockData>),
MatchBlock(Box<MatchBlockData>),
}Expand description
A single node in the SSH config AST.
Variants
BlankLine
An empty / blank line.
Comment
A comment line (including the leading #).
Fields
Directive(Box<DirectiveData>)
A standalone directive (not inside a Host/Match block).
HostBlock(Box<HostBlockData>)
A Host block containing nested directives.
MatchBlock(Box<MatchBlockData>)
A Match block containing nested directives.
Implementations
Sourceimpl ConfigNode
impl ConfigNode
Sourcepub fn as_host_block(&self) -> Option<(&[String], &[Self])>
pub fn as_host_block(&self) -> Option<(&[String], &[Self])>
If this is a HostBlock, return its patterns and inner nodes.
Sourcepub fn as_host_block_mut(&mut self) -> Option<&mut Vec<Self>>
pub fn as_host_block_mut(&mut self) -> Option<&mut Vec<Self>>
If this is a HostBlock, return mutable access to its nodes.
Sourcepub fn as_directive(&self) -> Option<(&str, &str)>
pub fn as_directive(&self) -> Option<(&str, &str)>
If this is a Directive, return its keyword and value.
Sourcepub fn as_directive_mut(&mut self) -> Option<(&mut String, &mut String)>
pub fn as_directive_mut(&mut self) -> Option<(&mut String, &mut String)>
If this is a Directive, return mutable access to its fields.